@@ -51,6 +51,9 @@ def _team_to_rst(name, info):
     service = info.get('service')
     if service:
         yield ':Service: ' + service
+    liaisons = info.get('liaisons')
+    if liaisons:
+        yield ':Liaisons: ' + ", ".join(liaisons)
     yield ''
     mission = info.get('mission', '').rstrip()
     if mission:
